# -*- coding: utf-8 -*-
"""billing-support

Revision ID: 9fc631b0e606
Revises: 82fe12ff1726
Create Date: 2023-12-20 11:31:34.522979

"""
import sqlalchemy as sa
from sqlalchemy.dialects import mysql

from alembic import op

# revision identifiers, used by Alembic.
revision = "9fc631b0e606"
down_revision = "82fe12ff1726"
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "billing_person",
        sa.Column("id", sa.Uuid(), nullable=False),
        sa.Column("name", sa.String(length=128), nullable=False),
        sa.Column("email", sa.String(length=128), nullable=False),
        sa.Column("address_line1", sa.String(length=128), nullable=False),
        sa.Column("address_line2", sa.String(length=128), nullable=True),
        sa.Column("city", sa.String(length=128), nullable=False),
        sa.Column("state", sa.String(length=128), nullable=False),
        sa.Column("zip", sa.String(length=128), nullable=False),
        sa.Column("country_code", sa.String(length=3), nullable=False),
        sa.Column("phone_country_code", sa.String(length=6), nullable=False),
        sa.Column("phone_number", sa.String(length=128), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "billing_invoice",
        sa.Column("id", sa.Uuid(), nullable=False),
        sa.Column("user_id", sa.Uuid(), nullable=False),
        sa.Column("customer_id", sa.Uuid(), nullable=False),
        sa.Column(
            "payment_status",
            sa.Enum(
                "PENDING", "COMPLETED", "CANCELED", "EXPIRED", name="invoicestatus"
            ),
            nullable=False,
        ),
        sa.Column("payment_failure_reason", sa.Text(), nullable=True),
        sa.Column("payment_provider_reference", sa.String(length=256), nullable=True),
        sa.Column("paid_at", sa.DateTime(), nullable=True),
        sa.ForeignKeyConstraint(
            ["customer_id"],
            ["billing_person.id"],
        ),
        sa.ForeignKeyConstraint(
            ["user_id"],
            ["user.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "billing_product",
        sa.Column("id", sa.Uuid(), nullable=False),
        sa.Column("invoice_id", sa.Uuid(), nullable=False),
        sa.Column("name", sa.String(length=64), nullable=False),
        sa.Column("description", sa.String(length=64), nullable=False),
        sa.Column("quantity", sa.Integer(), nullable=False),
        sa.Column("price", sa.Integer(), nullable=False),
        sa.Column("team_id", sa.Uuid(), nullable=True),
        sa.Column("stripe_key", sa.String(length=32), nullable=False),
        sa.ForeignKeyConstraint(
            ["invoice_id"],
            ["billing_invoice.id"],
        ),
        sa.ForeignKeyConstraint(
            ["team_id"],
            ["team.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
    )
    op.add_column("team", sa.Column("owner_permissions", sa.Integer(), nullable=False))
    op.add_column("team", sa.Column("member_permissions", sa.Integer(), nullable=False))
    op.add_column("team", sa.Column("public_permissions", sa.Integer(), nullable=False))
    op.add_column("team", sa.Column("paid_until", sa.Date(), nullable=True))
    op.drop_column("team", "allow_create_topics")
    op.drop_column("team", "type")
    op.add_column("user_team", sa.Column("permissions", sa.Integer(), nullable=True))
    op.drop_column("user_team", "can_modify_documents")
    op.drop_column("user_team", "can_invite_users")
    op.drop_column("user_team", "can_post_documents")
    op.drop_column("user_team", "can_delete_documents")
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "user_team",
        sa.Column(
            "can_delete_documents",
            mysql.TINYINT(display_width=1),
            autoincrement=False,
            nullable=False,
        ),
    )
    op.add_column(
        "user_team",
        sa.Column(
            "can_post_documents",
            mysql.TINYINT(display_width=1),
            autoincrement=False,
            nullable=False,
        ),
    )
    op.add_column(
        "user_team",
        sa.Column(
            "can_invite_users",
            mysql.TINYINT(display_width=1),
            autoincrement=False,
            nullable=False,
        ),
    )
    op.add_column(
        "user_team",
        sa.Column(
            "can_modify_documents",
            mysql.TINYINT(display_width=1),
            autoincrement=False,
            nullable=False,
        ),
    )
    op.drop_column("user_team", "permissions")
    op.add_column(
        "team",
        sa.Column(
            "type", mysql.ENUM("PUBLIC", "RESTRICTED", "PRIVATE"), nullable=False
        ),
    )
    op.add_column(
        "team",
        sa.Column(
            "allow_create_topics",
            mysql.TINYINT(display_width=1),
            autoincrement=False,
            nullable=False,
        ),
    )
    op.drop_column("team", "paid_until")
    op.drop_column("team", "public_permissions")
    op.drop_column("team", "member_permissions")
    op.drop_column("team", "owner_permissions")
    op.drop_table("billing_product")
    op.drop_table("billing_invoice")
    op.drop_table("billing_person")
    # ### end Alembic commands ###
